<!-- Do not edit this file. It is automatically generated by API Documenter. -->

[Home](./index.md) &gt; [sip.js](./sip.js.md) &gt; [Registerer](./sip.js.registerer.md) &gt; [retryAfter](./sip.js.registerer.retryafter.md)

## Registerer.retryAfter property

The number of seconds to wait before retrying to register.

<b>Signature:</b>

```typescript
get retryAfter(): number | undefined;
```

## Remarks

When the server rejects a registration request, if it provides a suggested duration to wait before retrying, that value is available here when and if the state transitions to `Unsubscribed`<!-- -->. It is also available during the callback to `onReject` after a call to `register`<!-- -->. (Note that if the state if already `Unsubscribed`<!-- -->, a rejected request created by `register` will not cause the state to transition to `Unsubscribed`<!-- -->. One way to avoid this case is to dispose of `Registerer` when unregistered and create a new `Registerer` for any attempts to retry registering.)

## Example


```ts
// Checking for retry after on state change
registerer.stateChange.addListener((newState) => {
  switch (newState) {
    case RegistererState.Unregistered:
      const retryAfter = registerer.retryAfter;
      break;
  }
});

// Checking for retry after on request rejection
registerer.register({
  requestDelegate: {
    onReject: () => {
      const retryAfter = registerer.retryAfter;
    }
  }
});

```

